![Logo](https://user-images.githubusercontent.com/8171465/89018959-393bb680-d33a-11ea-86ee-2055b574f23e.png)


# PAYWIX 2.0

[![DeepSource](https://static.deepsource.io/deepsource-badge-light-mini.svg)](https://deepsource.io/gh/renjithsraj/paywix/?ref=repository-badge)
[![Downloads](https://static.pepy.tech/personalized-badge/paywix?period=total&units=international_system&left_color=black&right_color=orange&left_text=Downloads)](https://pepy.tech/project/paywix)

Paywix is a lightweight software development kit (SDK) for payment processing, designed specifically for Python-based applications. It has been expanded to support all Python-based applications. This allows developers to integrate payment processing into their applications using the familiar Python programming language and makes it easier to add this functionality to a wide range of applications.

### Currently supported Payment Gateways

- Payu


### Example Projects
  - [Payu Demo Django 4](https://github.com/renjithsraj/paywix_ecommerce)

  
### Installation
* Python > 3 Version

```python
1. pip install paywix
2. pipenv install paywix
```

### Plugins

Paywix is currently extended with the following plugins. Instructions on how to use them in your own application are detailed below.

| Plugin | README |
| ------ | ------ |
| PAYU | https://github.com/renjithsraj/paywix/blob/master/PAYU.md|

### Todos
 - Cashfree
 - Stripe
 - Braintree
 - CCavenue
 - gpay
 - phonepe
 - amazonpay

License
----

MIT

